==> gorilla-notes-0.4.0-20200914.094953-4.jar: public/js/compiled/cljs-runtime/module$node_modules$react_grid_layout$build$utils.js <==
import "./cljs_env.js";
shadow$provide.module$node_modules$react_grid_layout$build$utils=function(global,require,module,exports){function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{default:obj}}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=
1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:{};i%2?ownKeys(Object(source),!0).forEach(function(key){var value=source[key];key in target?Object.defineProperty(target,key,{value,enumerable:!0,configurable:!0,writable:!0}):target[key]=value}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}
function bottom(layout){for(var max=0,bottomY,i=0,len=layout.length;i<len;i++)bottomY=layout[i].y+layout[i].h,bottomY>max&&(max=bottomY);return max}function cloneLayoutItem(layoutItem){return{w:layoutItem.w,h:layoutItem.h,x:layoutItem.x,y:layoutItem.y,i:layoutItem.i,minW:layoutItem.minW,maxW:layoutItem.maxW,minH:layoutItem.minH,maxH:layoutItem.maxH,moved:!!layoutItem.moved,static:!!layoutItem.static,isDraggable:layoutItem.isDraggable,isResizable:layoutItem.isResizable}}function collides(l1,l2){return l1.i===
l2.i||l1.x+l1.w<=l2.x||l1.x>=l2.x+l2.w||l1.y+l1.h<=l2.y||l1.y>=l2.y+l2.h?!1:!0}function compact(layout,compactType,cols){for(var compareWith=getStatics(layout),sorted=sortLayoutItems(layout,compactType),out=Array(layout.length),i=0,len=sorted.length;i<len;i++){var l=cloneLayoutItem(sorted[i]);l.static||(l=compactItem(compareWith,l,compactType,cols,sorted),compareWith.push(l));out[layout.indexOf(sorted[i])]=l;l.moved=!1}return out}function resolveCompactionCollision(layout,item,moveToCoord,axis){var sizeProp=
heightWidth[axis];item[axis]+=1;for(var i=layout.map(function(layoutItem){return layoutItem.i}).indexOf(item.i)+1;i<layout.length;i++){var otherItem=layout[i];if(!otherItem.static){if(otherItem.y>item.y+item.h)break;collides(item,otherItem)&&resolveCompactionCollision(layout,otherItem,moveToCoord+item[sizeProp],axis)}}item[axis]=moveToCoord}function compactItem(compareWith,l,compactType,cols,fullLayout){var compactH="horizontal"===compactType;if("vertical"===compactType)for(l.y=Math.min(bottom(compareWith),
l.y);0<l.y&&!getFirstCollision(compareWith,l);)l.y--;else if(compactH)for(l.y=Math.min(bottom(compareWith),l.y);0<l.x&&!getFirstCollision(compareWith,l);)l.x--;for(;compactType=getFirstCollision(compareWith,l);)compactH?resolveCompactionCollision(fullLayout,l,compactType.x+compactType.w,"x"):resolveCompactionCollision(fullLayout,l,compactType.y+compactType.h,"y"),compactH&&l.x+l.w>cols&&(l.x=cols-l.w,l.y++);return l}function correctBounds(layout,bounds){for(var collidesWith=getStatics(layout),i=0,
len=layout.length;i<len;i++){var l=layout[i];l.x+l.w>bounds.cols&&(l.x=bounds.cols-l.w);0>l.x&&(l.x=0,l.w=bounds.cols);if(l.static)for(;getFirstCollision(collidesWith,l);)l.y++;else collidesWith.push(l)}return layout}function getLayoutItem(layout,id){for(var i=0,len=layout.length;i<len;i++)if(layout[i].i===id)return layout[i]}function getFirstCollision(layout,layoutItem){for(var i=0,len=layout.length;i<len;i++)if(collides(layout[i],layoutItem))return layout[i]}function getAllCollisions(layout,layoutItem){return layout.filter(function(l){return collides(l,
layoutItem)})}function getStatics(layout){return layout.filter(function(l){return l.static})}function moveElement(layout,l,x,y,isUserAction,preventCollision,compactType,cols){if(l.static&&!0!==l.isDraggable||l.y===y&&l.x===x)return layout;log("Moving element ".concat(l.i," to [").concat(String(x),",").concat(String(y),"] from [").concat(l.x,",").concat(l.y,"]"));var oldX=l.x,oldY=l.y;"number"===typeof x&&(l.x=x);"number"===typeof y&&(l.y=y);l.moved=!0;var sorted=sortLayoutItems(layout,compactType);
if("vertical"===compactType&&"number"===typeof y?oldY>=y:"horizontal"===compactType&&"number"===typeof x&&oldX>=x)sorted=sorted.reverse();x=getAllCollisions(sorted,l);if(preventCollision&&x.length)return log("Collision prevented on ".concat(l.i,", reverting.")),l.x=oldX,l.y=oldY,l.moved=!1,layout;preventCollision=0;for(oldX=x.length;preventCollision<oldX;preventCollision++)oldY=x[preventCollision],log("Resolving collision between ".concat(l.i," at [").concat(l.x,",").concat(l.y,"] and ").concat(oldY.i,
" at [").concat(oldY.x,",").concat(oldY.y,"]")),oldY.moved||(layout=oldY.static?moveElementAwayFromCollision(layout,oldY,l,isUserAction,compactType,cols):moveElementAwayFromCollision(layout,l,oldY,isUserAction,compactType,cols));return layout}function moveElementAwayFromCollision(layout,collidesWith,itemToMove,isUserAction,compactType,cols){var compactH="horizontal"===compactType,compactV="horizontal"!==compactType,preventCollision=collidesWith.static;return isUserAction&&(isUserAction=!1,collidesWith=
{x:compactH?Math.max(collidesWith.x-itemToMove.w,0):itemToMove.x,y:compactV?Math.max(collidesWith.y-itemToMove.h,0):itemToMove.y,w:itemToMove.w,h:itemToMove.h,i:"-1"},!getFirstCollision(layout,collidesWith))?(log("Doing reverse collision on ".concat(itemToMove.i," up to [").concat(collidesWith.x,",").concat(collidesWith.y,"].")),moveElement(layout,itemToMove,compactH?collidesWith.x:void 0,compactV?collidesWith.y:void 0,isUserAction,preventCollision,compactType,cols)):moveElement(layout,itemToMove,
compactH?itemToMove.x+1:void 0,compactV?itemToMove.y+1:void 0,isUserAction,preventCollision,compactType,cols)}function sortLayoutItems(layout,compactType){return"horizontal"===compactType?sortLayoutItemsByColRow(layout):sortLayoutItemsByRowCol(layout)}function sortLayoutItemsByRowCol(layout){return layout.slice(0).sort(function(a,b){return a.y>b.y||a.y===b.y&&a.x>b.x?1:a.y===b.y&&a.x===b.x?0:-1})}function sortLayoutItemsByColRow(layout){return layout.slice(0).sort(function(a,b){return a.x>b.x||a.x===
b.x&&a.y>b.y?1:-1})}function validateLayout(layout){var contextName=1<arguments.length&&void 0!==arguments[1]?arguments[1]:"Layout",subProps=["x","y","w","h"];if(!Array.isArray(layout))throw Error(contextName+" must be an array!");for(var i=0,len=layout.length;i<len;i++){for(var item=layout[i],j=0;j<subProps.length;j++)if("number"!==typeof item[subProps[j]])throw Error("ReactGridLayout: "+contextName+"["+i+"]."+subProps[j]+" must be a number!");if(item.i&&"string"!==typeof item.i)throw Error("ReactGridLayout: "+
contextName+"["+i+"].i must be a string!");if(void 0!==item.static&&"boolean"!==typeof item.static)throw Error("ReactGridLayout: "+contextName+"["+i+"].static must be a boolean!");}}function log(){var _console;DEBUG&&(_console=console).log.apply(_console,arguments)}Object.defineProperty(exports,"__esModule",{value:!0});exports.bottom=bottom;exports.cloneLayout=function(layout){for(var newLayout=Array(layout.length),i=0,len=layout.length;i<len;i++)newLayout[i]=cloneLayoutItem(layout[i]);return newLayout};
exports.cloneLayoutItem=cloneLayoutItem;exports.childrenEqual=function(a,b){return(0,_lodash.default)(_react.default.Children.map(a,function(c){return c.key}),_react.default.Children.map(b,function(c){return c.key}))};exports.fastPositionEqual=function(a,b){return a.left===b.left&&a.top===b.top&&a.width===b.width&&a.height===b.height};exports.collides=collides;exports.compact=compact;exports.compactItem=compactItem;exports.correctBounds=correctBounds;exports.getLayoutItem=getLayoutItem;exports.getFirstCollision=
getFirstCollision;exports.getAllCollisions=getAllCollisions;exports.getStatics=getStatics;exports.moveElement=moveElement;exports.moveElementAwayFromCollision=moveElementAwayFromCollision;exports.perc=function(num){return 100*num+"%"};exports.setTransform=function(_ref){var top=_ref.top,width=_ref.width,height=_ref.height;_ref="translate(".concat(_ref.left,"px,").concat(top,"px)");return{transform:_ref,WebkitTransform:_ref,MozTransform:_ref,msTransform:_ref,OTransform:_ref,width:"".concat(width,"px"),
height:"".concat(height,"px"),position:"absolute"}};exports.setTopLeft=function(_ref2){var left=_ref2.left,width=_ref2.width,height=_ref2.height;return{top:"".concat(_ref2.top,"px"),left:"".concat(left,"px"),width:"".concat(width,"px"),height:"".concat(height,"px"),position:"absolute"}};exports.sortLayoutItems=sortLayoutItems;exports.sortLayoutItemsByRowCol=sortLayoutItemsByRowCol;exports.sortLayoutItemsByColRow=sortLayoutItemsByColRow;exports.synchronizeLayoutWithChildren=function(initialLayout,
children,cols,compactType){initialLayout=initialLayout||[];var layout=[];_react.default.Children.forEach(children,function(child,i){var exists=getLayoutItem(initialLayout,String(child.key));exists?layout[i]=cloneLayoutItem(exists):(!isProduction&&child.props._grid&&console.warn("`_grid` properties on children have been deprecated as of React 15.2. Please use `data-grid` or add your properties directly to the `layout`."),(exists=child.props["data-grid"]||child.props._grid)?(isProduction||validateLayout([exists],
"ReactGridLayout.children"),layout[i]=cloneLayoutItem(_objectSpread({},exists,{i:child.key}))):layout[i]=cloneLayoutItem({w:1,h:1,x:0,y:bottom(layout),i:String(child.key)}))});children=correctBounds(layout,{cols});return compact(children,compactType,cols)};exports.validateLayout=validateLayout;exports.compactType=function(props){props=props||{};var compactType=props.compactType;return!1===props.verticalCompact?null:compactType};exports.autoBindHandlers=function(el,fns){fns.forEach(function(key){return el[key]=
el[key].bind(el)})};exports.noop=exports.fastRGLPropsEqual=void 0;var _lodash=_interopRequireDefault(require("module$node_modules$lodash_DOT_isequal$index")),_react=_interopRequireDefault(require("module$node_modules$react$index")),isProduction=!1,DEBUG=!1;global=require("module$node_modules$react_grid_layout$build$fastRGLPropsEqual");exports.fastRGLPropsEqual=global;var heightWidth={x:"w",y:"h"};exports.noop=function(){}}
//# sourceMappingURL=module$node_modules$react_grid_layout$build$utils.js.map

==> gorilla-notes-0.5.3.jar: public/js/compiled/cljs-runtime/module$node_modules$react_grid_layout$build$utils.js <==
shadow$provide.module$node_modules$react_grid_layout$build$utils=function(global,require,module,exports){function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{default:obj}}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=
1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:{};i%2?ownKeys(Object(source),!0).forEach(function(key){var value=source[key];key in target?Object.defineProperty(target,key,{value:value,enumerable:!0,configurable:!0,writable:!0}):target[key]=value}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}
function bottom(layout){for(var max=0,bottomY,i=0,len=layout.length;i<len;i++)bottomY=layout[i].y+layout[i].h,bottomY>max&&(max=bottomY);return max}function cloneLayoutItem(layoutItem){return{w:layoutItem.w,h:layoutItem.h,x:layoutItem.x,y:layoutItem.y,i:layoutItem.i,minW:layoutItem.minW,maxW:layoutItem.maxW,minH:layoutItem.minH,maxH:layoutItem.maxH,moved:!!layoutItem.moved,static:!!layoutItem.static,isDraggable:layoutItem.isDraggable,isResizable:layoutItem.isResizable}}function collides(l1,l2){return l1.i===
l2.i||l1.x+l1.w<=l2.x||l1.x>=l2.x+l2.w||l1.y+l1.h<=l2.y||l1.y>=l2.y+l2.h?!1:!0}function compact(layout,compactType,cols){for(var compareWith=getStatics(layout),sorted=sortLayoutItems(layout,compactType),out=Array(layout.length),i=0,len=sorted.length;i<len;i++){var l=cloneLayoutItem(sorted[i]);l.static||(l=compactItem(compareWith,l,compactType,cols,sorted),compareWith.push(l));out[layout.indexOf(sorted[i])]=l;l.moved=!1}return out}function resolveCompactionCollision(layout,item,moveToCoord,axis){var sizeProp=
heightWidth[axis];item[axis]+=1;for(var i=layout.map(function(layoutItem){return layoutItem.i}).indexOf(item.i)+1;i<layout.length;i++){var otherItem=layout[i];if(!otherItem.static){if(otherItem.y>item.y+item.h)break;collides(item,otherItem)&&resolveCompactionCollision(layout,otherItem,moveToCoord+item[sizeProp],axis)}}item[axis]=moveToCoord}function compactItem(compareWith,l,compactType,cols,fullLayout){var compactH="horizontal"===compactType;if("vertical"===compactType)for(l.y=Math.min(bottom(compareWith),
l.y);0<l.y&&!getFirstCollision(compareWith,l);)l.y--;else if(compactH)for(l.y=Math.min(bottom(compareWith),l.y);0<l.x&&!getFirstCollision(compareWith,l);)l.x--;for(;compactType=getFirstCollision(compareWith,l);)compactH?resolveCompactionCollision(fullLayout,l,compactType.x+compactType.w,"x"):resolveCompactionCollision(fullLayout,l,compactType.y+compactType.h,"y"),compactH&&l.x+l.w>cols&&(l.x=cols-l.w,l.y++);return l}function correctBounds(layout,bounds){for(var collidesWith=getStatics(layout),i=0,
len=layout.length;i<len;i++){var l=layout[i];l.x+l.w>bounds.cols&&(l.x=bounds.cols-l.w);0>l.x&&(l.x=0,l.w=bounds.cols);if(l.static)for(;getFirstCollision(collidesWith,l);)l.y++;else collidesWith.push(l)}return layout}function getLayoutItem(layout,id){for(var i=0,len=layout.length;i<len;i++)if(layout[i].i===id)return layout[i]}function getFirstCollision(layout,layoutItem){for(var i=0,len=layout.length;i<len;i++)if(collides(layout[i],layoutItem))return layout[i]}function getAllCollisions(layout,layoutItem){return layout.filter(function(l){return collides(l,
layoutItem)})}function getStatics(layout){return layout.filter(function(l){return l.static})}function moveElement(layout,l,x,y,isUserAction,preventCollision,compactType,cols){if(l.static&&!0!==l.isDraggable||l.y===y&&l.x===x)return layout;log("Moving element ".concat(l.i," to [").concat(String(x),",").concat(String(y),"] from [").concat(l.x,",").concat(l.y,"]"));var oldX=l.x,oldY=l.y;"number"===typeof x&&(l.x=x);"number"===typeof y&&(l.y=y);l.moved=!0;var sorted=sortLayoutItems(layout,compactType);
if("vertical"===compactType&&"number"===typeof y?oldY>=y:"horizontal"===compactType&&"number"===typeof x&&oldX>=x)sorted=sorted.reverse();x=getAllCollisions(sorted,l);if(preventCollision&&x.length)return log("Collision prevented on ".concat(l.i,", reverting.")),l.x=oldX,l.y=oldY,l.moved=!1,layout;preventCollision=0;for(oldX=x.length;preventCollision<oldX;preventCollision++)oldY=x[preventCollision],log("Resolving collision between ".concat(l.i," at [").concat(l.x,",").concat(l.y,"] and ").concat(oldY.i,
" at [").concat(oldY.x,",").concat(oldY.y,"]")),oldY.moved||(layout=oldY.static?moveElementAwayFromCollision(layout,oldY,l,isUserAction,compactType,cols):moveElementAwayFromCollision(layout,l,oldY,isUserAction,compactType,cols));return layout}function moveElementAwayFromCollision(layout,collidesWith,itemToMove,isUserAction,compactType,cols){var compactH="horizontal"===compactType,compactV="horizontal"!==compactType,preventCollision=collidesWith.static;return isUserAction&&(isUserAction=!1,collidesWith=
{x:compactH?Math.max(collidesWith.x-itemToMove.w,0):itemToMove.x,y:compactV?Math.max(collidesWith.y-itemToMove.h,0):itemToMove.y,w:itemToMove.w,h:itemToMove.h,i:"-1"},!getFirstCollision(layout,collidesWith))?(log("Doing reverse collision on ".concat(itemToMove.i," up to [").concat(collidesWith.x,",").concat(collidesWith.y,"].")),moveElement(layout,itemToMove,compactH?collidesWith.x:void 0,compactV?collidesWith.y:void 0,isUserAction,preventCollision,compactType,cols)):moveElement(layout,itemToMove,
compactH?itemToMove.x+1:void 0,compactV?itemToMove.y+1:void 0,isUserAction,preventCollision,compactType,cols)}function sortLayoutItems(layout,compactType){return"horizontal"===compactType?sortLayoutItemsByColRow(layout):sortLayoutItemsByRowCol(layout)}function sortLayoutItemsByRowCol(layout){return layout.slice(0).sort(function(a,b){return a.y>b.y||a.y===b.y&&a.x>b.x?1:a.y===b.y&&a.x===b.x?0:-1})}function sortLayoutItemsByColRow(layout){return layout.slice(0).sort(function(a,b){return a.x>b.x||a.x===
b.x&&a.y>b.y?1:-1})}function validateLayout(layout){var contextName=1<arguments.length&&void 0!==arguments[1]?arguments[1]:"Layout",subProps=["x","y","w","h"];if(!Array.isArray(layout))throw Error(contextName+" must be an array!");for(var i=0,len=layout.length;i<len;i++){for(var item=layout[i],j=0;j<subProps.length;j++)if("number"!==typeof item[subProps[j]])throw Error("ReactGridLayout: "+contextName+"["+i+"]."+subProps[j]+" must be a number!");if(item.i&&"string"!==typeof item.i)throw Error("ReactGridLayout: "+
contextName+"["+i+"].i must be a string!");if(void 0!==item.static&&"boolean"!==typeof item.static)throw Error("ReactGridLayout: "+contextName+"["+i+"].static must be a boolean!");}}function log(){var _console;DEBUG&&(_console=console).log.apply(_console,arguments)}Object.defineProperty(exports,"__esModule",{value:!0});exports.bottom=bottom;exports.cloneLayout=function(layout){for(var newLayout=Array(layout.length),i=0,len=layout.length;i<len;i++)newLayout[i]=cloneLayoutItem(layout[i]);return newLayout};
exports.cloneLayoutItem=cloneLayoutItem;exports.childrenEqual=function(a,b){return(0,_lodash.default)(_react.default.Children.map(a,function(c){return c.key}),_react.default.Children.map(b,function(c){return c.key}))};exports.fastPositionEqual=function(a,b){return a.left===b.left&&a.top===b.top&&a.width===b.width&&a.height===b.height};exports.collides=collides;exports.compact=compact;exports.compactItem=compactItem;exports.correctBounds=correctBounds;exports.getLayoutItem=getLayoutItem;exports.getFirstCollision=
getFirstCollision;exports.getAllCollisions=getAllCollisions;exports.getStatics=getStatics;exports.moveElement=moveElement;exports.moveElementAwayFromCollision=moveElementAwayFromCollision;exports.perc=function(num){return 100*num+"%"};exports.setTransform=function(_ref){var top=_ref.top,width=_ref.width,height=_ref.height;_ref="translate(".concat(_ref.left,"px,").concat(top,"px)");return{transform:_ref,WebkitTransform:_ref,MozTransform:_ref,msTransform:_ref,OTransform:_ref,width:"".concat(width,"px"),
height:"".concat(height,"px"),position:"absolute"}};exports.setTopLeft=function(_ref2){var left=_ref2.left,width=_ref2.width,height=_ref2.height;return{top:"".concat(_ref2.top,"px"),left:"".concat(left,"px"),width:"".concat(width,"px"),height:"".concat(height,"px"),position:"absolute"}};exports.sortLayoutItems=sortLayoutItems;exports.sortLayoutItemsByRowCol=sortLayoutItemsByRowCol;exports.sortLayoutItemsByColRow=sortLayoutItemsByColRow;exports.synchronizeLayoutWithChildren=function(initialLayout,
children,cols,compactType){initialLayout=initialLayout||[];var layout=[];_react.default.Children.forEach(children,function(child,i){var exists=getLayoutItem(initialLayout,String(child.key));exists?layout[i]=cloneLayoutItem(exists):(!isProduction&&child.props._grid&&console.warn("`_grid` properties on children have been deprecated as of React 15.2. Please use `data-grid` or add your properties directly to the `layout`."),(exists=child.props["data-grid"]||child.props._grid)?(isProduction||validateLayout([exists],
"ReactGridLayout.children"),layout[i]=cloneLayoutItem(_objectSpread({},exists,{i:child.key}))):layout[i]=cloneLayoutItem({w:1,h:1,x:0,y:bottom(layout),i:String(child.key)}))});children=correctBounds(layout,{cols:cols});return compact(children,compactType,cols)};exports.validateLayout=validateLayout;exports.compactType=function(props){props=props||{};var compactType=props.compactType;return!1===props.verticalCompact?null:compactType};exports.autoBindHandlers=function(el,fns){fns.forEach(function(key){return el[key]=
el[key].bind(el)})};exports.noop=exports.fastRGLPropsEqual=void 0;var _lodash=_interopRequireDefault(require("module$node_modules$lodash_DOT_isequal$index")),_react=_interopRequireDefault(require("module$node_modules$react$index")),isProduction=!1,DEBUG=!1;global=require("module$node_modules$react_grid_layout$build$fastRGLPropsEqual");exports.fastRGLPropsEqual=global;var heightWidth={x:"w",y:"h"};exports.noop=function(){}}
//# sourceMappingURL=module$node_modules$react_grid_layout$build$utils.js.map
